==> fts_0.7.5.tar.gz: fts/src/tslib/tslib/vector.transform.hpp <==
///////////////////////////////////////////////////////////////////////////
// Copyright (C) 2008  Whit Armstrong                                    //
//                                                                       //
// This program is free software: you can redistribute it and/or modify  //
// it under the terms of the GNU General Public License as published by  //
// the Free Software Foundation, either version 3 of the License, or     //
// (at your option) any later version.                                   //
//                                                                       //
// This program is distributed in the hope that it will be useful,       //
// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         //
// GNU General Public License for more details.                          //
//                                                                       //
// You should have received a copy of the GNU General Public License     //
// along with this program.  If not, see <http://www.gnu.org/licenses/>. //
///////////////////////////////////////////////////////////////////////////

#ifndef VECTOR_TRANSFORM_HPP
#define VECTOR_TRANSFORM_HPP

#include <tslib/vector.transform/diff.hpp>
#include <tslib/vector.transform/fill.traits.hpp>
#include <tslib/vector.transform/fill.bwd.hpp>
#include <tslib/vector.transform/fill.fwd.hpp>
#include <tslib/vector.transform/fill.value.hpp>
#include <tslib/vector.transform/lag.lead.traits.hpp>
#include <tslib/vector.transform/lag.hpp>
#include <tslib/vector.transform/lead.hpp>
#include <tslib/vector.transform/since.na.traits.hpp>
#include <tslib/vector.transform/since.na.hpp>
#include <tslib/vector.transform/expanding.maximum.hpp>
#include <tslib/vector.transform/expanding.minimum.hpp>

#endif // VECTOR_TRANSFORM_HPP

==> fts_0.9.9.1.tar.gz: fts/src/tslib/tslib/vector.transform.hpp <==
///////////////////////////////////////////////////////////////////////////
// Copyright (C) 2008  Whit Armstrong                                    //
//                                                                       //
// This program is free software: you can redistribute it and/or modify  //
// it under the terms of the GNU General Public License as published by  //
// the Free Software Foundation, either version 3 of the License, or     //
// (at your option) any later version.                                   //
//                                                                       //
// This program is distributed in the hope that it will be useful,       //
// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         //
// GNU General Public License for more details.                          //
//                                                                       //
// You should have received a copy of the GNU General Public License     //
// along with this program.  If not, see <http://www.gnu.org/licenses/>. //
///////////////////////////////////////////////////////////////////////////

#ifndef VECTOR_TRANSFORM_HPP
#define VECTOR_TRANSFORM_HPP

#include <tslib/vector.transform/diff.hpp>
#include <tslib/vector.transform/fill.traits.hpp>
#include <tslib/vector.transform/fill.bwd.hpp>
#include <tslib/vector.transform/fill.fwd.hpp>
#include <tslib/vector.transform/fill.value.hpp>
#include <tslib/vector.transform/lag.lead.traits.hpp>
#include <tslib/vector.transform/since.na.traits.hpp>
#include <tslib/vector.transform/since.na.hpp>
#include <tslib/vector.transform/expanding.maximum.hpp>
#include <tslib/vector.transform/expanding.minimum.hpp>
#include <tslib/vector.transform/ema.hpp>
#include <tslib/vector.transform/ema.traits.hpp>

#endif // VECTOR_TRANSFORM_HPP
